import {Component, OnDestroy, OnInit} from '@angular/core';
import {LoginService} from '../../services/login.service';
import {Router} from '@angular/router';
import {takeWhile} from 'rxjs/operators';
import {StudentViewService} from '../../services/student-view.service';

@Component({
  selector: 'app-student-navbar',
  templateUrl: './student-navbar.component.html',
  styleUrls: ['./student-navbar.component.css']
})
export class StudentNavbarComponent implements OnInit, OnDestroy {

  public onDashboard: Boolean;
  public isAlive = true;

  constructor(private loginService: LoginService,
              private studentViewService: StudentViewService,
              private router: Router) {
  }

  public logout(): void {
    this.loginService.logout();
    this.router.navigate(['/login']);
  }

  ngOnInit(): void {
    this.studentViewService.onDashboard$.subscribe(flag => {
      this.onDashboard = !flag;
    }).add(takeWhile(() => this.isAlive));
  }

  ngOnDestroy(): void {
    this.isAlive = false;
  }

  public goToDashboard() {
    this.router.navigate(['sdashboard']);
  }
}
